@@ -95,7 +95,7 @@ void Group::setGroupName(const std::string& group_name)
   name_ = group_name;
 }
 
-void Group::addIndividual(const Individual& ind) throw (BadIdentifierException)
+void Group::addIndividual(const Individual& ind)
 {
   try
   {
@@ -107,7 +107,7 @@ void Group::addIndividual(const Individual& ind) throw (BadIdentifierException)
   individuals_.push_back(new Individual(ind));
 }
 
-void Group::addEmptyIndividual(const std::string& individual_id) throw (BadIdentifierException)
+void Group::addEmptyIndividual(const std::string& individual_id)
 {
   for (size_t i = 0; i < getNumberOfIndividuals(); i++)
   {
@@ -117,7 +117,7 @@ void Group::addEmptyIndividual(const std::string& individual_id) throw (BadIdent
   individuals_.push_back(new Individual(individual_id));
 }
 
-size_t Group::getIndividualPosition(const std::string& individual_id) const throw (IndividualNotFoundException)
+size_t Group::getIndividualPosition(const std::string& individual_id) const
 {
   for (size_t i = 0; i < getNumberOfIndividuals(); i++)
   {
@@ -127,7 +127,7 @@ size_t Group::getIndividualPosition(const std::string& individual_id) const thro
   throw IndividualNotFoundException("Group::getIndividualPosition: individual_id not found.", individual_id);
 }
 
-std::unique_ptr<Individual> Group::removeIndividualById(const std::string& individual_id) throw (IndividualNotFoundException)
+std::unique_ptr<Individual> Group::removeIndividualById(const std::string& individual_id)
 {
   try
   {
@@ -142,7 +142,7 @@ std::unique_ptr<Individual> Group::removeIndividualById(const std::string& indiv
   }
 }
 
-std::unique_ptr<Individual> Group::removeIndividualAtPosition(size_t individual_position) throw (IndexOutOfBoundsException)
+std::unique_ptr<Individual> Group::removeIndividualAtPosition(size_t individual_position)
 {
   if (individual_position >= individuals_.size())
     throw IndexOutOfBoundsException("Group::removeIndividualAtPosition.", individual_position, 0, individuals_.size());
@@ -151,7 +151,7 @@ std::unique_ptr<Individual> Group::removeIndividualAtPosition(size_t individual_
   return ind;
 }
 
-void Group::deleteIndividualById(const std::string& individual_id) throw (IndividualNotFoundException)
+void Group::deleteIndividualById(const std::string& individual_id)
 {
   try
   {
@@ -163,7 +163,7 @@ void Group::deleteIndividualById(const std::string& individual_id) throw (Indivi
   }
 }
 
-void Group::deleteIndividualAtPosition(size_t individual_position) throw (IndexOutOfBoundsException)
+void Group::deleteIndividualAtPosition(size_t individual_position)
 {
   try
   {
@@ -184,7 +184,7 @@ void Group::clear()
   individuals_.clear();
 }
 
-const Individual& Group::getIndividualById(const std::string& individual_id) const throw (IndividualNotFoundException)
+const Individual& Group::getIndividualById(const std::string& individual_id) const
 {
   for (size_t i = 0; i < individuals_.size(); i++)
   {
@@ -195,7 +195,6 @@ const Individual& Group::getIndividualById(const std::string& individual_id) con
 }
 
 const Individual& Group::getIndividualAtPosition(size_t individual_position) const
-throw (IndexOutOfBoundsException)
 {
   if (individual_position >= individuals_.size())
     throw IndexOutOfBoundsException("Group::getIndividualAtPosition: individual_position out of bounds.", individual_position, 0, individuals_.size());
@@ -224,28 +223,28 @@ size_t Group::getMaxNumberOfSequences() const
 
 // -- Dealing with individual's properties -----------------
 
-void Group::setIndividualSexAtPosition(size_t individual_position, const unsigned short sex) throw (IndexOutOfBoundsException)
+void Group::setIndividualSexAtPosition(size_t individual_position, const unsigned short sex)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualSexAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   individuals_[individual_position]->setSex(sex);
 }
 
-unsigned short Group::getIndividualSexAtPosition(size_t individual_position) const throw (IndexOutOfBoundsException)
+unsigned short Group::getIndividualSexAtPosition(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualSexAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   return individuals_[individual_position]->getSex();
 }
 
-void Group::setIndividualDateAtPosition(size_t individual_position, const Date& date) throw (IndexOutOfBoundsException)
+void Group::setIndividualDateAtPosition(size_t individual_position, const Date& date)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualDateAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   individuals_[individual_position]->setDate(date);
 }
 
-const Date& Group::getIndividualDateAtPosition(size_t individual_position) const throw (Exception)
+const Date& Group::getIndividualDateAtPosition(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualDateAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -259,14 +258,14 @@ const Date& Group::getIndividualDateAtPosition(size_t individual_position) const
   }
 }
 
-void Group::setIndividualCoordAtPosition(size_t individual_position, const Point2D<double>& coord) throw (IndexOutOfBoundsException)
+void Group::setIndividualCoordAtPosition(size_t individual_position, const Point2D<double>& coord)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualCoordAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   individuals_[individual_position]->setCoord(coord);
 }
 
-const Point2D<double>& Group::getIndividualCoordAtPosition(size_t individual_position) const throw (Exception)
+const Point2D<double>& Group::getIndividualCoordAtPosition(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualCoordAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -280,14 +279,14 @@ const Point2D<double>& Group::getIndividualCoordAtPosition(size_t individual_pos
   }
 }
 
-void Group::setIndividualLocalityAtPosition(size_t individual_position, const Locality<double>* locality) throw (IndexOutOfBoundsException)
+void Group::setIndividualLocalityAtPosition(size_t individual_position, const Locality<double>* locality)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualLocalityAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   individuals_[individual_position]->setLocality(locality);
 }
 
-const Locality<double>& Group::getIndividualLocalityAtPosition(size_t individual_position) const throw (Exception)
+const Locality<double>& Group::getIndividualLocalityAtPosition(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualLocalityAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -301,7 +300,7 @@ const Locality<double>& Group::getIndividualLocalityAtPosition(size_t individual
   }
 }
 
-void Group::addIndividualSequenceAtPosition(size_t individual_position, size_t sequence_position, const Sequence& sequence) throw (Exception)
+void Group::addIndividualSequenceAtPosition(size_t individual_position, size_t sequence_position, const Sequence& sequence)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::addIndividualSequenceAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -323,7 +322,7 @@ void Group::addIndividualSequenceAtPosition(size_t individual_position, size_t s
   }
 }
 
-const Sequence& Group::getIndividualSequenceByName(size_t individual_position, const string& sequence_name) const throw (Exception)
+const Sequence& Group::getIndividualSequenceByName(size_t individual_position, const string& sequence_name) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualSequenceByName: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -341,7 +340,7 @@ const Sequence& Group::getIndividualSequenceByName(size_t individual_position, c
   }
 }
 
-const Sequence& Group::getIndividualSequenceAtPosition(size_t individual_position, size_t sequence_position) const throw (Exception)
+const Sequence& Group::getIndividualSequenceAtPosition(size_t individual_position, size_t sequence_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -359,7 +358,7 @@ const Sequence& Group::getIndividualSequenceAtPosition(size_t individual_positio
   }
 }
 
-void Group::deleteIndividualSequenceByName(size_t individual_position, const string& sequence_name) throw (Exception)
+void Group::deleteIndividualSequenceByName(size_t individual_position, const string& sequence_name)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::deleteIndividualSequenceByName: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -377,7 +376,7 @@ void Group::deleteIndividualSequenceByName(size_t individual_position, const str
   }
 }
 
-void Group::deleteIndividualSequenceAtPosition(size_t individual_position, size_t sequence_position) throw (Exception)
+void Group::deleteIndividualSequenceAtPosition(size_t individual_position, size_t sequence_position)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::deleteIndividualSequenceAtPosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -395,14 +394,14 @@ void Group::deleteIndividualSequenceAtPosition(size_t individual_position, size_
   }
 }
 
-bool Group::hasIndividualSequences(size_t individual_position) const throw (IndexOutOfBoundsException)
+bool Group::hasIndividualSequences(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::hasIndividualSequences: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   return individuals_[individual_position]->hasSequences();
 }
 
-vector<string> Group::getIndividualSequencesNames(size_t individual_position) const throw (Exception)
+vector<string> Group::getIndividualSequencesNames(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualSequencesNames: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -416,7 +415,7 @@ vector<string> Group::getIndividualSequencesNames(size_t individual_position) co
   }
 }
 
-size_t Group::getIndividualSequencePosition(size_t individual_position, const string& sequence_name) const throw (Exception)
+size_t Group::getIndividualSequencePosition(size_t individual_position, const string& sequence_name) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualSequencePosition: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -434,7 +433,7 @@ size_t Group::getIndividualSequencePosition(size_t individual_position, const st
   }
 }
 
-size_t Group::getIndividualNumberOfSequences(size_t individual_position) const throw (Exception)
+size_t Group::getIndividualNumberOfSequences(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualNumberOfSequences: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -448,21 +447,21 @@ size_t Group::getIndividualNumberOfSequences(size_t individual_position) const t
   }
 }
 
-void Group::setIndividualSequences(size_t individual_position, const MapSequenceContainer& msc) throw (IndexOutOfBoundsException)
+void Group::setIndividualSequences(size_t individual_position, const MapSequenceContainer& msc)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualSequences: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   individuals_[individual_position]->setSequences(msc);
 }
 
-void Group::setIndividualGenotype(size_t individual_position, const MultilocusGenotype& genotype) throw (IndexOutOfBoundsException)
+void Group::setIndividualGenotype(size_t individual_position, const MultilocusGenotype& genotype)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualGenotype: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   individuals_[individual_position]->setGenotype(genotype);
 }
 
-void Group::initIndividualGenotype(size_t individual_position, size_t loci_number) throw (Exception)
+void Group::initIndividualGenotype(size_t individual_position, size_t loci_number)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::initIndividualGenotype: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -480,21 +479,21 @@ void Group::initIndividualGenotype(size_t individual_position, size_t loci_numbe
   }
 }
 
-void Group::deleteIndividualGenotype(size_t individual_position) throw (IndexOutOfBoundsException)
+void Group::deleteIndividualGenotype(size_t individual_position)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::deleteIndividualGenotype: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   individuals_[individual_position]->deleteGenotype();
 }
 
-bool Group::hasIndividualGenotype(size_t individual_position) const throw (IndexOutOfBoundsException)
+bool Group::hasIndividualGenotype(size_t individual_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::hasIndividualGenotype: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
   return individuals_[individual_position]->hasGenotype();
 }
 
-void Group::setIndividualMonolocusGenotype(size_t individual_position, size_t locus_position, const MonolocusGenotype& monogen) throw (Exception)
+void Group::setIndividualMonolocusGenotype(size_t individual_position, size_t locus_position, const MonolocusGenotype& monogen)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualMonolocusGenotype: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -512,7 +511,7 @@ void Group::setIndividualMonolocusGenotype(size_t individual_position, size_t lo
   }
 }
 
-void Group::setIndividualMonolocusGenotypeByAlleleKey(size_t individual_position, size_t locus_position, const std::vector<size_t>& allele_keys) throw (Exception)
+void Group::setIndividualMonolocusGenotypeByAlleleKey(size_t individual_position, size_t locus_position, const std::vector<size_t>& allele_keys)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualMonolocusGenotypeByAlleleKey: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -534,7 +533,7 @@ void Group::setIndividualMonolocusGenotypeByAlleleKey(size_t individual_position
   }
 }
 
-void Group::setIndividualMonolocusGenotypeByAlleleId(size_t individual_position, size_t locus_position, const std::vector<std::string>& allele_id, const LocusInfo& locus_info) throw (Exception)
+void Group::setIndividualMonolocusGenotypeByAlleleId(size_t individual_position, size_t locus_position, const std::vector<std::string>& allele_id, const LocusInfo& locus_info)
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::setIndividualMonolocusGenotypeByAlleleId: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -556,7 +555,7 @@ void Group::setIndividualMonolocusGenotypeByAlleleId(size_t individual_position,
   }
 }
 
-const MonolocusGenotype&  Group::getIndividualMonolocusGenotype(size_t individual_position, size_t locus_position) const throw (Exception)
+const MonolocusGenotype&  Group::getIndividualMonolocusGenotype(size_t individual_position, size_t locus_position) const
 {
   if (individual_position >= getNumberOfIndividuals())
     throw IndexOutOfBoundsException("Group::getIndividualMonolocusGenotype: individual_position out of bounds.", individual_position, 0, getNumberOfIndividuals());
@@ -584,7 +583,7 @@ bool Group::hasSequenceData() const
   return false;
 }
 
-const Alphabet* Group::getAlphabet() const throw (NullPointerException)
+const Alphabet* Group::getAlphabet() const
 {
   for (size_t i = 0; i < getNumberOfIndividuals(); i++)
   {
