@@ -269,7 +269,7 @@ PolymorphismMultiGContainer PolymorphismMultiGContainerTools::permutIntraGroupAl
 
   for (set<size_t>::const_iterator g = groups.begin(); g != groups.end(); g++) // for each group
   {
-    int nb_ind_in_group = 0;
+    size_t nb_ind_in_group = 0;
 
     vector< vector<size_t> > nb_alleles_for_inds;
     nb_alleles_for_inds.resize(loc_num);
@@ -314,7 +314,7 @@ PolymorphismMultiGContainer PolymorphismMultiGContainerTools::permutIntraGroupAl
       // Build the new PolymorphismMultiGContainer
       vector<size_t> k(loc_num, 0);
 
-      for (int ind = 0; ind < nb_ind_in_group; ind++)
+      for (size_t ind = 0; ind < nb_ind_in_group; ind++)
       {
         MultilocusGenotype tmp_mg(loc_num);
         for (size_t j = 0; j < loc_num; j++)
